#import <Cocoa/Cocoa.h>
#import "RIRipEngine.h"
#import "RIRipMode.h"
//#import "RIDiscPatchBuilder.h"


@interface RIRipController : NSObject 
{
    NSString				*deviceName;
    NSString				*mountPath;
    NSString				*moviesFolder;
    NSString				*title;
    NSString				*discTitle;
    NSString				*discidentTitle;
    NSString				*fingerprint;
    NSMutableDictionary		*status;
    BOOL					 wasCancelled;
    BOOL					 shouldEjectWhenFinished;

    uint64_t				 capacity;
    uint64_t				 bytesToCopy;
    uint64_t				 bytesCopied;
    FSRef					*output;
    NSOperationQueue		*ripOperationQueue;
    NSOperationQueue		*writebackOperationQueue;
    NSMutableDictionary		*handlesForWriting;
    NSMutableArray			*statisticsWindow;

    NSDate					*firstRead;
    NSDate					*lastReadInWindow;
    uint64_t				 bytesInWindow;

	// nsv
	RIRipMode				 ripMode;
	BOOL					 isUDF;
	BOOL					 remasteringScrubInstructions;
	id						 delegate;
	//RIDiscPatchBuilder		*discPatchBuilder;
	NSArray					*filterTitleSetArray;
	NSMutableDictionary		*filterTitleSetFileDictionary;
	uint64_t				 queueSize;
}

- (id) initWithURL:(NSURL*)url fingerprint:(NSString*)fingerprint discTitle:(NSString*)discTitle;
- (id) initWithDeviceName:(NSString*)deviceName fingerprint:(NSString*)fingerprint discTitle:(NSString*)discTitle;

// nsv
- (void) analyzeWithEngine:(Class)engine;
- (void) startWithEngine:(Class)engine filterFor:(NSArray *)titleSetArray;
//- (void) startWithEngine:(Class)engine filterFor:(NSArray *)titleSetArray patchWith:(RIDiscPatchBuilder*)discPatchBuilder;
- (void) startWithEngine2:(Class)engine;

- (void) startWithEngine:(Class)engine;
- (void) cancel;
- (BOOL) isFiltered;

// nsv
@property (assign) id				 delegate;
@property (assign) BOOL				 remasteringScrubInstructions;
@property (assign) uint64_t			 queueSize;

@property (readonly) NSString		*deviceName;
@property (retain) NSString			*moviesFolder;
@property (retain) NSString			*mountPath;
@property (retain) NSString			*title;
@property (readonly) NSString		*discTitle;
@property (readonly) NSString		*fingerprint;
@property (readonly) NSDictionary	*status;
@property (assign) uint64_t			 capacity;
@property (readonly) NSString		*dvdMediaName;
@property (assign) BOOL				 shouldEjectWhenFinished;
@property (readonly) BOOL			 wasCancelled;

@end

extern NSString* const RIStatusReasonForFailureKey;
extern NSString* const RIStatusBytesPerSecondKey;
extern NSString* const RIStatusEstimatedTimeKey;
extern NSString* const RIStatusPercentageCompleteKey;
extern NSString* const RIStatusCurrentFileKey;
extern NSString* const RIStatusStateKey;
extern NSString* const RIStatusBytesCopiedKey;
extern NSString* const RIStatusBytesToCopyKey;
extern NSString* const RIStatusDVDMediaFilePathKey;
extern NSString* const RIStatusPlanOfAttackKey;
extern NSString* const RIStatusQueueSizeKey;

extern NSString* const RIStatusStateReady;
extern NSString* const RIStatusStatePreparing;
extern NSString* const RIStatusStateRipping;
extern NSString* const RIStatusStateZeroingSpace;
extern NSString* const RIStatusStateFinished;
extern NSString* const RIStatusStateCancelled;
extern NSString* const RIStatusStateFailed;

extern NSString* const RIRipControllerException;









